use 5.008;
use strict;
use warnings;

package Data::Conveyor::Value::Enum;
BEGIN {
  $Data::Conveyor::Value::Enum::VERSION = '1.101690';
}
# ABSTRACT: Stage-based conveyor-belt-like ticket handling system


# Inherit from Class::Scaffold::Base because get_valid_values_list is
# presumably going to ask the delegate. Need to put Class::Value::Enum first
# so it can find the more specific comparable() in Class::Value. If you need
# to ask the storage for the list of valid values, your subclass should
# inherit from Class::Scaffold::Storable instead.
use parent qw(
  Class::Value::Enum
  Class::Scaffold::Base
);
1;


__END__
=pod

=head1 NAME

Data::Conveyor::Value::Enum - Stage-based conveyor-belt-like ticket handling system

=head1 VERSION

version 1.101690

=head1 INSTALLATION

See perlmodinstall for information and options on installing Perl modules.

=head1 BUGS AND LIMITATIONS

No bugs have been reported.

Please report any bugs or feature requests through the web interface at
L<http://rt.cpan.org>.

=head1 AVAILABILITY

The latest version of this module is available from the Comprehensive Perl
Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
site near you, or see
L<http://search.cpan.org/dist/Data-Conveyor/>.

The development version lives at
L<http://github.com/hanekomu/Data-Conveyor/>.
Instead of sending patches, please fork this project using the standard git
and github infrastructure.

=head1 AUTHORS

  Marcel Gruenauer <marcel@cpan.org>
  Florian Helmberger <fh@univie.ac.at>
  Achim Adam <ac@univie.ac.at>
  Mark Hofstetter <mh@univie.ac.at>
  Heinz Ekker <ek@univie.ac.at>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2004 by Marcel Gruenauer.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

